@@ -160,7 +160,7 @@ class RedisDao(object):
         return self
 
     def __exit__(self, exc_type, exc_value, exc_trace):
-        self.__exit__()
+        self.__db.close()
 
     def qsize(self, queue):
         return self.__db.llen(queue)  # 返回队列里面list内元素的数量
