@@ -252,10 +252,15 @@ def bar(obj, return_index=False, bar_len_total=50, bar_str='█', end='', step=1
     if isinstance(obj, int):
         obj = range(obj)
     assert isinstance(obj, Iterable), 'obj必须是整型或者可迭代对象'
+    assert len(obj) > 0, '可迭代对象长度为0'
     obj_len = len(obj)
     start_time = time.time()
+    now = obj[-1]
     for now, item in enumerate(obj, start=1):
-        yield now - 1, item if return_index else item
+        if return_index:
+            yield now - 1, item
+        else:
+            yield item
         if now % step == 0:
             bar_len_now = bar_len_total * now // obj_len  # 当前轮次需要打印的bar_str个数
             end_time = time.time()
